@@ -50,9 +50,9 @@ gsh_check_row()
 void
 gsh_parse_arguments(int argc, char **argv)
 {
- unsigned int    counter;
+ unsigned int counter;
 
- for (counter = 1; counter < argc; counter++)
+ for (counter = 1; counter < (unsigned int)argc; counter++)
  {
   if (argv[counter][0] == '-')
   {
