@@ -38,6 +38,8 @@
 #include "option_options.h"
 #include "updated_options.h"
 #include "add_options.h"
+#include "dialog_options.h"
+#include "file_dialog.h"
 
 GtkWidget      *gsh_window;
 GtkWidget      *gsh_hbox;
