@@ -31,3 +31,13 @@ gsh_add_label(char *text)
  gsh_manage(label);
 }
 
+void
+gsh_set_label(GtkWidget *label, char *text)
+{
+	char *markup;
+	
+	markup=g_markup_printf_escaped
+		("<span size=\"small\"><tt>%s</tt></span>", text);
+	gtk_label_set_markup(GTK_LABEL(label), markup);
+	g_free(markup);
+}
