@@ -39,10 +39,25 @@ gsh_handle_switch_arguments(int argc, char **argv, unsigned int *counter)
  	switch (argv[(*counter)][1])
  	{
 		case 'a':
-			gsh_handle_add_arguments(argc, argv, counter);
+			gsh_handle_add_arguments(
+				argc, 
+				argv, 
+				counter);
+			break;
+		case 'd':	
+			gsh_handle_dialog_arguments(
+				argc, 
+				argv, 
+				counter);
 			break;
 		case 'o':
-			gsh_handle_option_arguments(argc, argv, counter);
+			gsh_handle_option_arguments(
+				argc, 
+				argv, 
+				counter);
+			break;
+		default:
+			printf("%s:  undefined\n", argv[(*counter)]);
 			break;
 	}
 }
