@@ -38,12 +38,6 @@ void
 gsh_add_update(void (*function)(char *, void *),
         char *command, void *widget);
 
-void    
-gsh_update_label(char *command, void *widget);
-
-void    
-gsh_add_updated_label(char *command);
-
 void    
 gsh_start_updates();
 
